=======
Credits
=======

Development Lead
----------------

* Cameron Yick <cameron.yick@enigma.com>

Contributors
------------

* Dmitry Budaev <condemil@gmail.com>
* Bharat Kalluri
* Stephen Clark <steveclarkcode@gmail.com>
* Davis Thames
* Nima Yazdanmehr
* Michael MacCormack
* David Minnen
* Tobias Kaesser <t.kaesser@gmail.com>
